@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2018, Stefan Schwarzer <sschwarzer@sschwarzer.net>
+# Copyright (C) 2009-2023, Stefan Schwarzer <sschwarzer@sschwarzer.net>
 # and ftputil contributors (see `doc/contributors.txt`)
 # See the file LICENSE for licensing terms.
 
@@ -95,11 +95,12 @@ class TestPublicServers:
 
     # List of pairs with server name and a directory "guaranteed to exist"
     # under the login directory which is assumed to be the root directory.
-    servers = [  # Posix format
+    servers = [
+        # Posix format
         ("ftp.de.debian.org", "debian"),
-        # ("ftp.gnome.org", "pub"),
-        ("ftp.heanet.ie", "pub"),
         ("ftp.heise.de", "pub"),
+        ("ftp.tu-chemnitz.de", "pub"),
+        ("ftp.uni-erlangen.de", "pub"),
         # DOS/Microsoft format
         # Do you know any FTP servers that use Microsoft format?
         # `ftp.microsoft.com` doesn't seem to be reachable anymore.
