@@ -47,7 +47,9 @@ def expected_time_shift():
     server, later it used UTC time, and now it uses the local timezone again.
     I wasn't able to find out why or how I can control this.
     """
-    raw_time_shift = (datetime.datetime.now() - datetime.datetime.utcnow()).seconds
+    raw_time_shift = (
+        datetime.datetime.now() - datetime.datetime.now(datetime.timezone.utc)
+    ).seconds
     # To be safe, round the above value to units of 900 s (1/4 hours).
     return round(raw_time_shift / 900.0) * 900
 
@@ -290,6 +292,7 @@ class TestRemoval(RealFTPTest):
         assert host.path.isfile("_testfile_")
         # Monkey-patch session `delete` call.
         old_delete = host._session.delete
+
         def failing_delete(path):
             # Simulate the case where the file is removed on the server, but a
             # proper reply doesn't get through to the client. It doesn't matter
@@ -376,6 +379,7 @@ class TestRemoval(RealFTPTest):
         assert host.path.isdir("_testdir_")
         # Monkey-patch session `rmd` call.
         old_rmd = host._session.rmd
+
         def failing_rmd(path):
             # Simulate the case where the directory is removed on the server,
             # but a proper reply doesn't get through to the client. It doesn't
@@ -637,6 +641,7 @@ class TestRename(RealFTPTest):
         file2_stat = host.stat("_testfile2_")
         # Monkey-patch session `rename` call.
         old_rename = host._session.rename
+
         def failing_rename(source, target):
             # Simulate the case where the rename completely or partially
             # succeeds on the server, but a proper reply doesn't get through to
@@ -644,6 +649,7 @@ class TestRename(RealFTPTest):
             # `error_temp` or `error_perm`.
             old_rename(source, target)
             raise ftplib.error_perm("simulated error")
+
         host._session.rename = failing_rename
         #
         with pytest.raises(ftputil.error.PermanentError):
@@ -705,9 +711,7 @@ class TestStat(RealFTPTest):
         #  time. Arbitrarily allow two minutes here to account for limited time
         #  precision from parsing the directory.
         server_mtime = host.path.getmtime(file_name)
-        client_mtime = (
-            datetime.datetime.utcnow().replace(tzinfo=datetime.timezone.utc).timestamp()
-        )
+        client_mtime = datetime.datetime.now(datetime.timezone.utc).timestamp()
         assert not (client_mtime - server_mtime > 120)
 
     def test_issomething_for_nonexistent_directory(self):
