@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2021, Stefan Schwarzer <sschwarzer@sschwarzer.net>
+# Copyright (C) 2014-2024, Stefan Schwarzer <sschwarzer@sschwarzer.net>
 # and ftputil contributors (see `doc/contributors.txt`)
 # See the file LICENSE for licensing terms.
 
@@ -7,13 +7,19 @@ Unit tests for session factory helpers.
 """
 
 import ftplib
+import functools
 import sys
 
+import pytest
+
 import ftputil.path_encoding
 import ftputil.session
 import ftputil.tool
 
 
+UTF8_FEAT_STRING = " UTF8\r\n"
+
+
 # Inherit from `ftplib.FTP` to get past the subclass check in
 # `ftputil.session.session_factory`.
 class MockSession(ftplib.FTP):
@@ -23,10 +29,11 @@ class MockSession(ftplib.FTP):
 
     encoding = ftputil.path_encoding.FTPLIB_DEFAULT_ENCODING
 
-    def __init__(self, encoding=None):
+    def __init__(self, encoding=None, feat_command_output=""):
         self.calls = []
         if encoding is not None:
             self.encoding = encoding
+        self._feat_command_output = feat_command_output
 
     def add_call(self, *args):
         self.calls.append(args)
@@ -34,12 +41,20 @@ class MockSession(ftplib.FTP):
     def connect(self, host, port):
         self.add_call("connect", host, port)
 
-    def set_debuglevel(self, value):
-        self.add_call("set_debuglevel", value)
-
     def login(self, user, password):
         self.add_call("login", user, password)
 
+    def sendcmd(self, command):
+        self.add_call("sendcmd", command)
+        if command == "FEAT":
+            return self._feat_command_output
+        else:
+            # Dummy
+            return ""
+
+    def set_debuglevel(self, value):
+        self.add_call("set_debuglevel", value)
+
     def set_pasv(self, flag):
         self.add_call("set_pasv", flag)
 
@@ -58,13 +73,31 @@ class TestSessionFactory:
     trigger the expected calls.
     """
 
+    @staticmethod
+    def _expected_session_calls_for_encoding_handling(encoding, feat_command_output):
+        """
+        Return the FTP session calls that the session factory should perform.
+        """
+        if encoding is None:
+            encoding = ftputil.path_encoding.FTPLIB_DEFAULT_ENCODING
+        if encoding.upper() == "UTF-8":
+            if feat_command_output == UTF8_FEAT_STRING:
+                return [("sendcmd", "FEAT"), ("sendcmd", "OPTS UTF8 ON")]
+            else:
+                return [("sendcmd", "FEAT")]
+        else:
+            return []
+
     def test_defaults(self):
         """
         Test defaults (apart from base class).
         """
         factory = ftputil.session.session_factory(base_class=MockSession)
         session = factory("host", "user", "password")
-        assert session.calls == [("connect", "host", 21), ("login", "user", "password")]
+        assert session.calls == [
+            ("connect", "host", 21),
+            ("login", "user", "password"),
+        ] + self._expected_session_calls_for_encoding_handling(None, "")
 
     def test_different_port(self):
         """
@@ -75,7 +108,7 @@ class TestSessionFactory:
         assert session.calls == [
             ("connect", "host", 2121),
             ("login", "user", "password"),
-        ]
+        ] + self._expected_session_calls_for_encoding_handling(None, "")
 
     def test_use_passive_mode(self):
         """
@@ -90,7 +123,7 @@ class TestSessionFactory:
             ("connect", "host", 21),
             ("login", "user", "password"),
             ("set_pasv", True),
-        ]
+        ] + self._expected_session_calls_for_encoding_handling(None, "")
         # Active mode
         factory = ftputil.session.session_factory(
             base_class=MockSession, use_passive_mode=False
@@ -100,7 +133,7 @@ class TestSessionFactory:
             ("connect", "host", 21),
             ("login", "user", "password"),
             ("set_pasv", False),
-        ]
+        ] + self._expected_session_calls_for_encoding_handling(None, "")
 
     def test_encrypt_data_channel(self):
         """
@@ -113,7 +146,7 @@ class TestSessionFactory:
             ("connect", "host", 21),
             ("login", "user", "password"),
             ("prot_p",),
-        ]
+        ] + self._expected_session_calls_for_encoding_handling(None, "")
         #
         factory = ftputil.session.session_factory(
             base_class=EncryptedMockSession, encrypt_data_channel=True
@@ -123,39 +156,71 @@ class TestSessionFactory:
             ("connect", "host", 21),
             ("login", "user", "password"),
             ("prot_p",),
-        ]
+        ] + self._expected_session_calls_for_encoding_handling(None, "")
         # Without encrypted data channel.
         factory = ftputil.session.session_factory(
             base_class=EncryptedMockSession, encrypt_data_channel=False
         )
         session = factory("host", "user", "password")
-        assert session.calls == [("connect", "host", 21), ("login", "user", "password")]
+        assert session.calls == [
+            ("connect", "host", 21),
+            ("login", "user", "password"),
+        ] + self._expected_session_calls_for_encoding_handling(None, "")
 
-    def test_encoding(self):
+    @pytest.mark.parametrize(
+        "encoding, feat_command_output, expected_encoding, expected_session_calls_for_encoding_handling",
+        [
+            # Expected session calls for the first two tuples depend on the
+            # Python version and are determined in the code below.
+            #
+            # For the `FEAT` command output we consider only wether the " UTF8"
+            # string is present. A real `FEAT` response from a server would be
+            # more complicated.
+            (None, "", ftputil.path_encoding.FTPLIB_DEFAULT_ENCODING, None),
+            (
+                None,
+                UTF8_FEAT_STRING,
+                ftputil.path_encoding.FTPLIB_DEFAULT_ENCODING,
+                None,
+            ),
+            ("UTF-8", "", "UTF-8", [("sendcmd", "FEAT")]),
+            (
+                "UTF-8",
+                UTF8_FEAT_STRING,
+                "UTF-8",
+                [("sendcmd", "FEAT"), ("sendcmd", "OPTS UTF8 ON")],
+            ),
+            ("latin1", "", "latin1", []),
+            ("latin1", UTF8_FEAT_STRING, "latin1", []),
+        ],
+    )
+    def test_encoding(
+        self,
+        encoding,
+        feat_command_output,
+        expected_encoding,
+        expected_session_calls_for_encoding_handling,
+    ):
         """
-        Test setting the default encoding and a custom encoding.
+        If `encoding` has the given values, the result should be the same as
+        documented.
         """
-        # Default encoding
+        # Special handling for default encoding.
+        base_class = functools.partial(
+            MockSession, feat_command_output=feat_command_output
+        )
         factory = ftputil.session.session_factory(
             base_class=MockSession,
+            encoding=encoding,
         )
         session = factory("host", "user", "password")
-        assert session.calls == [
+        expected_session_calls = [
             ("connect", "host", 21),
             ("login", "user", "password"),
-        ]
-        assert session.encoding == ftputil.path_encoding.FTPLIB_DEFAULT_ENCODING
-        # Custom encoding
-        factory = ftputil.session.session_factory(
-            base_class=MockSession,
-            encoding="UTF-8",
+        ] + self._expected_session_calls_for_encoding_handling(
+            encoding, feat_command_output
         )
-        session = factory("host", "user", "password")
-        assert session.calls == [
-            ("connect", "host", 21),
-            ("login", "user", "password"),
-        ]
-        assert session.encoding == "UTF-8"
+        assert session.encoding == expected_encoding
 
     def test_debug_level(self):
         """
@@ -167,4 +232,4 @@ class TestSessionFactory:
             ("connect", "host", 21),
             ("set_debuglevel", 1),
             ("login", "user", "password"),
-        ]
+        ] + self._expected_session_calls_for_encoding_handling(None, "")
